@@ -1,9 +1,9 @@
 newton <-
-function(fun,derf,x0,eps,maxit=20,silent=TRUE){
+function(fun,derf,x0,eps,maxit=20,silent=TRUE,tun=1){
 iter=0
 repeat{
 iter=iter+1
-x2=x0-fun(x0)/derf(x0)
+x2=x0-(fun(x0)/derf(x0))/tun
 if (abs(x0-x2)<=eps) break
 if (iter>=maxit) stop("Maximum iteration exceeded")
 x0=x2
